<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="state.title"
        width="700px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="superRef" :rules="state.formRules" label-width="150px" >
        <el-form-item v-if="state.isAdmin" label="企业:" prop="companyId">
          <el-select v-model="state.form.companyId" placeholder="请选择" clearable @change="getDeptList">
            <el-option
                v-for="item in state.companyList"
                :key="item.id"
                :label="item.name"
                :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="受审核部门:" prop="deptId">
          <el-select
              clearable
              v-model="state.form.deptId"
              :disabled="state.title =='查看'"
              filterable
              placeholder="选择受审核部门"
              style="width: 100%"
              @change="getCaluses"
          >
            <el-option
                v-for="item in state.deptList"
                :key="item.deptId"
                :label="item.deptName"
                :value="item.deptId"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="受审核人:" prop="internalAuditCheckPeople">
          <el-select clearable v-model="state.form.internalAuditCheckPeople" :disabled="state.title =='查看'" value-key="userId" filterable multiple placeholder="受审核人" style="width: 100%">
            <el-option
                v-for="item in state.userList"
                :key="item.userId"
                :label="item.name"
                :value="item"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="内审员:" prop="auditId">
          <el-select clearable v-model="state.form.auditId" :disabled="state.title =='查看'" filterable placeholder="内审员" style="width: 100%">
            <el-option
                v-for="item in state.interUserList"
                :key="item.userId"
                :label="item.name"
                :value="item.userId"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="内审时间:" prop="auditDate">
          <el-date-picker
              v-model="state.form.auditDate"
              type="datetime"
              value-format="YYYY-MM-DD HH:mm:ss"
              placeholder="请选择内审时间"
          />
        </el-form-item>
        <el-form-item label="对应认证标准条款（过程）:" prop="caluseNum">
          <el-input v-model.trim="state.form.caluseNum" type="textarea" readonly :autosize="{ minRows: 2 }"></el-input>
        </el-form-item>
        <el-form-item label="检查内容:" prop="caluseContent">
          <el-input v-model.trim="state.form.caluseContent" type="textarea" readonly :autosize="{ minRows: 2 }"></el-input>
        </el-form-item>
        <el-form-item label="检查记录:" prop="checkRecord">
          <el-input v-model.trim="state.form.checkRecord" type="textarea" :readonly="state.title =='查看'" :autosize="{ minRows: 2 }"></el-input>
        </el-form-item>
        <el-form-item label="不符合标记:" prop="inconsistent">
          <el-input v-model.trim="state.form.inconsistent" type="textarea" :readonly="state.title =='查看'" :autosize="{ minRows: 2 }"></el-input>
        </el-form-item>
<!--        <el-form-item label="文件:" prop="filePath">-->
<!--          <el-upload accept=".doc,.docx" :action="state.uploadUrl" :headers="state.header" method="post" :on-success="(res, uploadFile)=>handleAvatarSuccess(res, uploadFile)" :on-exceed="showTip" :limit='state.fileLimit' v-model:file-list="state.fileList" :before-upload="picSize" :on-remove="(file, uploadFiles)=>handleRemove(file, uploadFiles)" >-->
<!--            <el-button type="primary">点击上传</el-button>-->
<!--            <template #tip>-->
<!--              <div class="el-upload__tip">支持上传.doc、.docx格式文档，尺寸小于5M，最多可上传1份</div>-->
<!--            </template>-->
<!--          </el-upload>-->
<!--        </el-form-item>-->
      </el-form>
      <template #footer v-if="state.title !='查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs, defineEmits, nextTick, onMounted} from 'vue'
import {ElMessage} from "element-plus";
import {Base64} from "js-base64"
import {getToken} from "@/utils/auth";
import {
  addInternalAuditCheck, getInternalAuditCheckInfo,
  updateInternalAuditCheck
} from "@/api/innerReview/meetingReview";
import {getDepart} from "@/api/orgStructure/depart";
import {listUser} from "@/api/system/user";

const emit = defineEmits(["getList"]);
const dialogVisible = ref(false)
const superRef = ref()
const checkFiles = (rule, value, callback) => {
  if (state.fileList.length == 0) {
    callback(new Error('请上传文件'))
  } else {
    callback()
  }
}
const state = reactive({
  title: '',
  form: {
    id: null,
    deptId: null,
    internalAuditCheckPeople:[],
    auditId: null,
    auditDate: '',
    caluseNum: '',
    caluseContent: '',
    checkRecord: '',
    inconsistent: '',
    companyId: null
  },
  formRules:{
    companyId: [{ required: true, message: '请选择企业', trigger: 'blur' }],
    deptId: [{ required: true, message: '请选择受审核部门', trigger: 'blur' }],
    internalAuditCheckPeople: [{ required: true, message: '请选择受审核人', trigger: 'blur' }],
    auditId: [{ required: true, message: '请选择内审员', trigger: 'blur' }],
    auditDate: [{ required: true, message: '请选择内审时间',  trigger: 'blur' }],
    checkRecord: [{ required: true, message: '请填写检查记录',  trigger: 'blur' }]
  },
  isAdmin: false,
  companyList: [],
  deptList: [],
  userList: [],
  interUserList: [],
  uploadUrl: import.meta.env.VITE_APP_BASE_API + '/system/common/uploadFile',
  header: {
    Authorization: getToken()
  },
  fileLimit: 1,
  fileList: []
})
onMounted(() => {

});

const openDialog = async (type, value,companyId, isAdmin, companyList) => {
  state.isAdmin = isAdmin
  if(isAdmin){
    state.companyList = companyList
  }
  await getUserList()
  await getDepartList(companyId)
  state.title = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看'
  state.form.companyId = companyId
  if(state.title == '编辑'||state.title == '查看'){
    Object.keys(state.form).forEach(key => {
      if (key in value) {
        state.form[key] = value[key]
      }
    })
    await getInfo(value.id)

    // if(value.filePath) {
    //   const obj = {
    //     url: value.filePath,
    //     name: '模板文件'
    //   }
    //   state.fileList = [obj]
    // }
  }
  dialogVisible.value = true
}


const onSubmit = async () => {
  const valid = await superRef.value.validate();
  if(valid){
    state.form.internalAuditCheckPeople = state.form.internalAuditCheckPeople.map(item=>{
      return {
        id: item.id || null,
        auditUserId: item.userId,
        companyId: item.companyId || null,
        auditUserName: item.name
      }
    })
    if(state.title == '新增'){
      const {id,...data} = state.form
      const res = await addInternalAuditCheck(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }else{
      const res = await updateInternalAuditCheck(state.form)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }
  }
}

const getInfo = async (id)=> {
  const res = await getInternalAuditCheckInfo({id: id})
  if(res.code == 200){
    state.form.internalAuditCheckPeople = res.data.internalAuditCheckPeople?.map(item=>{
      return {
        id: item.id,
        auditId: item.auditId,
        userId: item.auditUserId,
        name: item.auditUserName,
        companyId: item.companyId
      }
    })
  }else{
    ElMessage.warning(res.message)
  }
}

const getDeptList = async ()=>{
  state.form.deptId = null
  state.form.internalAuditCheckPeople = []
  state.form.auditId = null
  state.form.caluseNum = ''
  state.form.caluseContent = ''
  await getDepartList(state.form.companyId)
  await getUserList()
}

const getDepartList = async (companyId)=> {
  const params = {
    companyId: companyId
  }
  const res = await getDepart(params)
  if(res.code == 200){
    state.deptList = res.data
  }else{
    ElMessage.warning(res.message)
  }
}

const getUserList = async ()=> {
  const res = await listUser({pageIndex: 1,pageSize: 999})
  if(res.code == 200){
    state.userList = res.data.list?res.data.list.map(item=>{
      const user = item.id
      const {id, ...data} = item
      return {
        ...data,
        userId: user
      }
    }):[]
    if(state.form.deptId){
      state.interUserList = state.userList.filter(i=>i.deptId !== state.form.deptId)
    }else{
      state.interUserList = state.userList
    }
  }else{
    ElMessage.warning(res.message)
  }
}

const getCaluses = async ()=>{
  await getUserList()
  const deptCaluses = state.deptList.find(i=>i.deptId == state.form.deptId)?.caluseVO1List
  if(deptCaluses && Array.isArray(deptCaluses)){
    state.form.caluseNum = deptCaluses.map(i=>i.clauseNum).join('、')
    state.form.caluseContent = deptCaluses.map(i=>i.content).join('；\n')
  }
}
// const handleAvatarSuccess = (res, uploadFile) => {
//   if(res.code == 200){
//     state.form.filePath = res.data.path
//     state.form.format = '.' + res.data.filename.split('.')[1]
//   }else{
//     state.fileList = []
//     ElMessage({
//       type: 'warning',
//       message: '文件上传失败'
//     })
//   }
// }
//
// const showTip =()=>{
//   ElMessage({
//     type: 'warning',
//     message: '超出文件上传数量'
//   });
// }
// const picSize = async (rawFile) => {
//   if(rawFile.size / 1024 / 1024 > 5){
//     ElMessage({
//       type: 'warning',
//       message: '文件大小不能超过5M'
//     });
//     return false
//   }
// };
// const handleRemove = async (file, uploadFiles) => {
//   let path = state.form.filePath;
//   await delPic({path: path}).then(res => {
//     if(res.code == 200){
//       // ElMessage({
//       //   type: 'success',
//       //   message: '文件已删除'
//       // })
//       state.form.filePath = ''
//       state.form.format = ''
//     }else{
//       ElMessage({
//         type: 'warning',
//         message: res.message
//       })
//     }
//   }).catch(() => {
//     state.form.imgUrl = ''
//   });
// }

const handleClose = () => {
  state.form = {
    id: null,
    deptId: null,
    internalAuditCheckPeople:[],
    auditId: null,
    auditDate: '',
    caluseNum: '',
    caluseContent: '',
    checkRecord: '',
    inconsistent: '',
    companyId: null
  }
  state.fileList = []
  superRef.value.clearValidate();
  superRef.value.resetFields()
  dialogVisible.value = false;
}

defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
